| Title: | Work with Hyperspectral Data, i.e. Spectra + Meta Information (Spatial, Time, Concentration, ...) |
|---|---|
| Description: | Comfortable ways to work with hyperspectral data sets, i.e. spatially or time-resolved spectra, or spectra with any other kind of information associated with each of the spectra. The spectra can be data as obtained in XRF, UV/VIS, Fluorescence, AES, NIR, IR, Raman, NMR, MS, etc. More generally, any data that is recorded over a discretized variable, e.g. absorbance = f(wavelength), stored as a vector of absorbance values for discrete wavelengths is suitable. |
| Authors: | Claudia Beleites [aut, cre, dtc] (ORCID: <https://orcid.org/0000-0003-1626-154X>), Alois Bonifacio [ctb, dtc], Marcel Dahms [ctb], Björn Egert [ctb], Simon Fuller [ctb], Vilmantas Gegzna [aut] (ORCID: <https://orcid.org/0000-0002-9500-5167>), Rustam Guliev [ctb], Bryan A. Hanson [aut] (ORCID: <https://orcid.org/0000-0003-3536-8246>), Michael Hermes [ctb], Martin Kammer [dtc], Roman Kiselev [aut], Sebastian Mellor [ctb], Erick Oduniyi [aut], Valter Sergo [aut] |
| Maintainer: | Claudia Beleites <[email protected]> |
| License: | GPL (>= 3) + file LICENSE |
| Version: | 0.200.0.9000 |
| Built: | 2026-06-05 20:39:39 UTC |
| Source: | https://github.com/r-hyperspec/hyperspec |